#!/usr/bin/env node
'use strict';

const parse = require('minimist');
const polkadot = require('./');
const $ = require('./fn');

const exit = (msg, err) => {
	$.error(msg, err);
	process.exit(1);
};

const args = parse(process.argv.slice(2), {
	alias: {h: 'host', p: 'port'},
	default: {h: '0.0.0.0', p: 3000},
	boolean: ['help']
});

if (args.help) {
	return $.help();
}

let fn;
let file = args._.pop();

if (!file) {
	const pkg = $.find('./package');
	file = pkg && require(pkg).main || $.find('./');
}

if (file[0] !== '/') {
	file = $.find(file);
}

if (!file) {
	return exit('Please provide a file!');
}

try {
	fn = require(file);
	if (fn && typeof fn === 'object') {
		fn = fn.default;
	}
} catch (err) {
	return exit('Error when importing file', err);
}

if (typeof fn !== 'function') {
	return exit('Please export a function.');
}

polkadot(fn).listen(args.port, args.host, err => {
	if (err) {
		return exit('inside', err);
	}
	console.log(`> Listening on http://${args.host}:${args.port}`);
});
